@@ -253,7 +253,7 @@ class Tier(object):
         
         interpolated_point_times = np.arange(point1.time, point2.time, step)[1:]
         
-        interpolated_points = [Point(time, value, superior_Tier=self) for time, value in zip(interpolated_point_times, [point1.time, point2.time], [point1.value, point2.value])]
+        interpolated_points = [Point(time, value, superior_Tier=self) for time, value in zip(interpolated_point_times, np.interp(interpolated_point_times, [point1.time, point2.time], [point1.value, point2.value]))]
         
         self.add_points(interpolated_points, _by.POINT)
 
