@@ -15,6 +15,10 @@ class Parameter(dict):
                 if type(value) != str:
                     raise Exception(
                         '\'write_to_file.duplicate\' only accepts strings.')
+                if value.strip() == '':
+                    raise Exception(
+                        'Empty string cannot serve as extension.')
+                
 
             if key in ('write_to_file.replace', 'write_to_file.duplicate', 'points.ignore_missing_point'):
                 if type(value) != bool:
